#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Mar 25 16:08:46 2021

@author: arsi
"""

import pytest

from tscfat.Utils.process_decorator import process_decorator
from tscfat.Analysis import summary_statistics
from tscfat.Utils.argument_loader import setup_pd

class TestProcessDecorator(object):
    
    
    def test_process_decorator(self):
        
        @process_decorator
        def summary(df,name):
            ser = df[name] 
            _ = summary_statistics.summary_statistics(ser,
                                                      "{} summary".format(name),
                                                      window = 14,
                                                      savepath = False,
                                                      savename = False,
                                                      test = False)
        
        df = setup_pd()
        cols = ['level']
        summary(df,cols)
        
        
    
        



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Mar 29 15:43:00 2021

@author: arsii

Test function for stability calculation.

"""

import pytest
import numpy as np

from tscfat.Analysis.calculate_stability import compute_stability

class TestCalculateStability(object):
    
    def test_compute_stability(self):
        """
        Test compute stability function:
            - Proper arguments return non-empty stability score.
            - Self similarity matrix given as array raises an error
            - 1D self similarity matrix raises an error
            - Non-square self similarity matrix raises an error
            - Kernel size larger than the self similarity matrix raises an error
            - Edge given as float raises an error
            - Edge given as negative integer raises an error
    
        Returns
        -------
        None.
    
        """
        
        test_argument = np.random.rand(5,5)
        np.fill_diagonal(test_argument,1)
        stab = compute_stability(test_argument,edge=1)
        assert stab is not None
                
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            compute_stability([[1,0,0],[0,1,0],[0,0,1]])
        expected_error_msg = "Self similarity matrix is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_stability(np.array([1,0,0]))
        expected_error_msg = "Self similarity matrix is not 2-dimensional."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_stability(np.random.rand(3,2))
        expected_error_msg = "Self similarity matrix is not square."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_stability(np.random.rand(3,3),edge=10)
        expected_error_msg = "Kernel size is larger than the self similarity matrix."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
    
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            compute_stability(test_argument,float(1))
        expected_error_msg = "Edge is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_stability(test_argument,-1)
        expected_error_msg = "Edge should be positive, non zero integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 31 22:52:40 2021

@author: ikaheia1

Tests for argument loader.
    1) setup_pd should return a pandas dataframe
    2) setup_ps should return a pandas series
    3) setup_np shoulf return a numpy array

"""

import numpy as np
import pandas as pd

from tscfat.Utils.argument_loader import setup_pd, setup_np, setup_ps

class TestProcessDecorator(object):
    
    def test_setup_pd(self):
        """
        Test that setup_pd function returns a pandas dataframe

        Returns
        -------
        None.

        """
        
        test_argument = setup_pd()
        
        assert isinstance(test_argument, pd.DataFrame)
    
    def test_setup_ps(self):
        """
        Test that setup_pd function returns a pandas series

        Returns
        -------
        None.

        """
        
        test_argument = setup_ps()
        
        assert isinstance(test_argument, pd.Series)

    def test_setup_np(self):
        """
        Test that setup_pd function returns a numpy array.

        Returns
        -------
        None.

        """
        
        test_argument = setup_np()
        
        assert isinstance(test_argument, np.ndarray)
        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:13 2021

@author: arsii

Test for degree distribution calculation.

"""

import numpy as np
import pytest

from tscfat.Analysis.degree_of_distribution import distribution_degree

#TODO! write docstings
class TestDegreeOfDistribution(object):
    
    def test_distribution_degree(self):
        y_1 = np.array([3,5,6,3,3,3,7,5,4])
        y_2 = np.array([3,3,3,3,3,3,3])
        y_3 = np.array([2,5,2,5,2,5,2])
        y_4 = np.array([1,1,1,1,7,7,7])
        y_5 = np.array([1,7,1,7,1,7,1])
        y_6 = np.array([1,2,3,4,5,6,7])
        y_7 = np.array([4,5,3,6,2,7,1])
     
        assert distribution_degree(y_1,6,7) == pytest.approx(0.41666666666666663)
        assert distribution_degree(y_2,6,7) == pytest.approx(0.0)
        assert distribution_degree(y_3,6,7) == pytest.approx(0.5515873015873016)
        assert distribution_degree(y_4,6,7) == pytest.approx(0.6349206349206349)
        assert distribution_degree(y_5,6,7) == pytest.approx(0.6349206349206349)
        assert distribution_degree(y_6,6,7) == pytest.approx(1.0)
        assert distribution_degree(y_7,6,7) == pytest.approx(1.0)
       
    def test_bad_series(self):
        y_1 = [1,2,3,4,5,6]
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            distribution_degree(y_1,6,6)
        expected_error_msg = "Given time series is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_bad_scale(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            distribution_degree(y_1,float(6),6)
        expected_error_msg = "Given scale is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_bad_window(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            distribution_degree(y_1,6,"6")
        expected_error_msg = "Given window length is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_neg_scale(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            distribution_degree(y_1,-6,6)
        expected_error_msg = "Given scale is negative."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_large_window(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            distribution_degree(y_1,6,10)
        expected_error_msg = "Improper window length."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
      


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Mar 25 16:08:46 2021

@author: arsi

Test for doi2int function.

"""

import pytest

from tscfat.Utils.doi2int import doi2index
from tscfat.Utils.argument_loader import setup_pd, setup_np

class TestDoi2Int(object):
        
    def test_doi2int(self):
        """
        Test with proper arguments.

        Returns
        -------
        None.

        """
        df = setup_pd()
        test_argument = (2011,3,1),(2011,6,1)
        a,b = doi2index(test_argument, df)
        
        assert a == pytest.approx(4478.12331851853)
        assert b == pytest.approx(4570.12331851853)
        
        
    def test_doi2int_bad_arguments(self):
        
        test_argument = (2011,3,1),(2011,6,1)
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            a,b = doi2index(test_argument, setup_np())
        expected_error_msg = "df is not a pandas dataframe."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            a,b = doi2index(123, setup_np())
        expected_error_msg = "Doi is not a tuple."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
       
        



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:08 2021

@author: arsii

Test function for time series clustering.

"""

import numpy as np

from tscfat.Analysis.cluster_timeseries import cluster_timeseries, _plot_clusters

class TestClusterTimeseries(object):
    
    def test_cluster_timeseries(self):
        """ Test that the clusters are correctly assigned.
        

        Returns
        -------
        None.

        """
   
        sample = np.array([[1,1,1,2,2,2],[2,2,2,3,3,3],[1,2,3,4,5,6],[4,5,6,7,8,9]],np.int32)
        clusters = cluster_timeseries(sample, False, False, title="Clustered timeseries", n=2, mi=5, mib=5, rs=0)
        np.testing.assert_array_equal(clusters,np.array([0,0,1,1])), "Clusters are not correctly assigned."
        
    def test_plot_clusters(self):
        """ Test that the _plot_clusters function returns something.
        

        Returns
        -------
        None.

        """
      
        sample = np.array([1,1,1,2,2,2,3,3,3])
        res = _plot_clusters(sample, title="test", xlab="Timepoint", ylab="Cluster", savename = False, savepath = False, test = True)
        assert res is not None


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:16 2021

@author: arsii

Test for summary statistics.

"""
import pytest

from tscfat.Analysis.summary_statistics import summary_statistics, _plot_summary 
from tscfat.Utils.argument_loader import setup_pd, setup_ps


class TestSummaryStatistics(object):
    
    def test_summary_statistics(self):
        """
        Test Summary_statistics function. Test that Pandas data frame as an
        argument raises an error.
    
        Returns
        -------
        None.
    
        """
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            summary_statistics(setup_pd(),'Test title', savepath = False, savename = False, test = True)
        expected_error_msg = "Series is not a pandas Series."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
class TestSummaryPlot(object):
    
    def test_summary_plot(self):
        """
        Test that _plot_summary function returns something.

        Returns
        -------
        None.

        """
        
        test_argument = setup_ps()
        res = _plot_summary(test_argument, title="test", test=True)
        assert res is not None, "Returned figure is None type."


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:19:59 2021

@author: arsii

Test function for similarity calculation.

"""
import os
import pytest
import numpy as np

cwd = os.getcwd()
print(cwd)

from tscfat.Utils.argument_loader import setup_np, setup_pd
from tscfat.Analysis.calculate_similarity import calculate_similarity, calculate_distance

class TestCalculateSimilarity(object):
    
    def test_calculate_distance(self):
        """
        Test calculate_distance function. The test fails when:
            - Given array is not a numpy array
            - Given array is not 2 dimensional 
    
        Returns
        -------
        None.
    
        """
        test_argument = setup_pd()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            calculate_distance(test_argument)
        expected_error_msg = "Data format is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        test_argument2 = setup_np()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            calculate_distance(test_argument2)
        expected_error_msg = "Matrix is not 2 dimensional."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_calculate_similarity_proper(self):
        """
        Test calculate distance with proper argument.

        Returns
        -------
        None.

        """
                
        test_argument = np.array([[1,0.5,0],[0.5,1,0.5],[0,0.5,1]])
        Y_sim = calculate_distance(test_argument)
        
        assert isinstance(Y_sim, np.ndarray)
    
    def test_calculate_similarity(self):
        """
        Test calculate_similarity function. The test fails when:
            - Given array is not a numpy array
            - Given array is not 2 dimensional 
    
        Returns
        -------
        None.
    
        """
        
        test_argument = setup_pd()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            calculate_similarity(test_argument)
        expected_error_msg = "Data format is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        test_argument2 = setup_np()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            calculate_similarity(test_argument2)
        expected_error_msg = "Matrix is not 2 dimensional."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_calculate_distance_proper(self):
        """
        Test calculate similarity with proper argument.

        Returns
        -------
        None.

        """
        
        test_argument = np.array([[1,0.5,0],[0.5,1,0.5],[0,0.5,1]])
        Y_dis = calculate_distance(test_argument)
        
        assert isinstance(Y_dis, np.ndarray)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 31 23:04:32 2021

@author: ikaheia1

Test for file_names class.

"""

from tscfat.Utils.file_names import FileNames

class TestFileNames(object):
    
    def test_add(self):
        """
        Test add method.

        Returns
        -------
        None.

        """
        
        fn = FileNames()
        fn.add("alias","value")
        
        assert fn.alias == 'value'
        
        
    def test_list_filenames(self):
        """
        Test list_parameters method.

        Returns
        -------
        None.

        """
        fn = FileNames()
        fn.add('alias_1', 'value_1')
        fn.add('alias_2', 'value_2')
        
        assert fn.list_filenames() == {'alias_1': 'value_1', 'alias_2': 'value_2'}


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:15 2021

@author: arsii

Test for similarity plotting.

"""
import pytest
import numpy as np

from tscfat.Utils.argument_loader import setup_np, setup_pd
from tscfat.Analysis.plot_similarity import plot_similarity

#TODO! write docstrings

class TestPlotSimilarity(object):
    
    def test_bad_arguments(self):
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            plot_similarity(setup_pd(),setup_np(),setup_np(),test=True)
        expected_error_msg = "Similarity matrix type is not np.ndarray."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            plot_similarity(setup_np(),setup_pd(),setup_np(),test=True)
        expected_error_msg = "Novelty score array type is not np.ndarray."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)

    def test_plot_similarity(self):
    
        simmat = np.eye(50)
        novelty = np.ones(50)
        stability = np.ones(50)
        ker = np.array([[1,1,0,-1,-1],
                        [1,1,0,-1,-1],
                        [0,0,0,0,0],
                        [-1,-1,0,1,1],
                        [-1,-1,0,1,1]])
        
        ret = plot_similarity(simmat,
                              novelty,
                              stability,
                              title = "test",
                              doi = None,
                              savepath = False, 
                              savename = False,
                              ylim = (0,0.05),
                              threshold = 0,
                              axis = None,
                              kernel = ker,
                              test = True
                              )
        
        assert ret is not None


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 31 23:04:32 2021

@author: ikaheia1

Test for analysis paramters class.

"""

from tscfat.Utils.analysis_parameters import AnalysisParameters

class TestAnalysisParameters(object):
    
    def test_add(self):
        """
        Test add method.

        Returns
        -------
        None.

        """
        
        ap = AnalysisParameters()
        ap.add("alias","value")
        
        assert ap.alias == 'value'
        
        
    def test_list_parameters(self):
        """
        Test list_parameters method.

        Returns
        -------
        None.

        """
        ap = AnalysisParameters()
        ap.add('alias_1', 'value_1')
        ap.add('alias_2', 'value_2')
        
        assert ap.list_parameters() == {'alias_1': 'value_1', 'alias_2': 'value_2'}


#!/usr/bin/env python3#
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:19:57 2021

@author: arsii

Test function for novelty calculation.

"""

import pytest
import numpy as np

from tscfat.Analysis.calculate_novelty import compute_novelty, _create_kernel

class TestCalculateNovelty(object):
    
    def test_compute_novelty(self):
        """
        Test compute novelty function:
            - Proper arguments return non-empty novelty score array and kernel.
            - Self similarity matrix given as array raises an error
            - 1D self similarity matrix raises an error
            - Non-square self similarity matrix raises an error
            - Kernel size larger than the self similarity matrix raises an error
    
        Returns
        -------
        None.
    
        """
        
        
        test_argument = np.random.rand(5,5)
        np.fill_diagonal(test_argument,1)
        nov,ker = compute_novelty(test_argument,edge=1)
        assert nov is not None
        assert ker is not None
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            compute_novelty([[1,0,0],[0,1,0],[0,0,1]])
        expected_error_msg = "Self similarity matrix is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_novelty(np.array([1,0,0]))
        expected_error_msg = "Self similarity matrix is not 2-dimensional."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_novelty(np.random.rand(3,2))
        expected_error_msg = "Self similarity matrix is not square."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            compute_novelty(np.random.rand(3,3),edge=10)
        expected_error_msg = "Kernel size is larger than the self similarity matrix."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
      

    def test_create_kernel(self):
        """
        Test create kernel function:
            - Proper arguments yield an N x N numpy array
            - Edge given as float raises an error
            - Negative edge lenght raises an error
    
        Returns
        -------
        None.
    
        """
        res = _create_kernel(7)
        assert isinstance(res,np.ndarray), "Kernel is not a numpy array."
        assert (np.ndim(res) == 2), "Kernel is not a 2D array."
        assert res.shape[0]  == res.shape[1], "Kernel is not a square matrix." 
        
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            _create_kernel(float(1))
        expected_error_msg = "Edge is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
        with pytest.raises(AssertionError) as exc_info:
            _create_kernel(-1)
        expected_error_msg = "Edge should be positive, non zero integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Created on Mon Jan 18 14:06:42 2021

@author: arsii
"""

from distutils.core import setup
from setuptools import find_packages

setup(
  name = 'tscfat',         
  packages = find_packages(),   
  version = '0.0.2',      
  license='MIT',        
  description = 'A time series co-fluctuation analysis toolbox',   
  author = 'Arsi Ikaheimonen',                   
  author_email = 'arsi.ikaheimonen@gmail.com',      
  url = 'https://github.com/ArgonSilicon/tscfat',   
  download_url = 'https://github.com/ArgonSilicon/tscfat/archive/refs/tags/0.0.2.tar.gz',
  keywords = ['Timeseries', 'Exploratory', 'Analysis'],  
  install_requires=['nolds',
                    'sklearn',
                    'pytest',
                    'numpy',
                    'matplotlib',
                    'pandas',
                    'statsmodels',
                    'tslearn',
                    'seaborn'],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Science/Research',      
    'Topic :: Scientific/Engineering :: Medical Science Apps.', #?
    'License :: OSI Approved :: MIT License',   #P
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Apr  1 11:36:22 2021

@author: arsii
"""

import pytest

from tscfat.Utils.plot_decorator import plot_decorator
from tscfat.Analysis.plot_timeseries import plot_timeseries
from tscfat.Utils.argument_loader import setup_pd

class TestPlotDecorator(object):
    
    
    def test_plot_decorator(self):
        
        df = setup_pd()
        name = ['level']
        _ = plot_timeseries(df,
                        name,
                        title = "test title",
                        roll = False, 
                        xlab = "Time", 
                        ylab = "Value", 
                        ylim = False, 
                        savename = False, 
                        savepath = False,
                        highlight = False, 
                        test=True
                        )
    
  


# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:14 2021

@author: arsii

Test for fluctuation intensity calculation.

"""
import numpy as np
import pytest

from tscfat.Analysis.fluctuation_intensity import fluctuation_intensity

#TODO! write the docstings
class TestFluctuationIntensity(object):
    
    def test_fluctuation_intensity(self):
        y_2 = np.array([3,3,3,3,3,3,3])
        y_3 = np.array([2,5,2,5,2,5,2])
        y_4 = np.array([1,1,1,1,7,7,7])
        y_5 = np.array([1,7,1,7,1,7,1])
        y_6 = np.array([1,2,3,4,5,6,7])
        y_7 = np.array([4,5,3,6,2,7,1])   
        assert fluctuation_intensity(y_2,6,7) == pytest.approx(0.0)
        assert fluctuation_intensity(y_3,6,7) == pytest.approx(0.5)
        assert fluctuation_intensity(y_4,6,7) == pytest.approx(0.16666666666666666)
        assert fluctuation_intensity(y_5,6,7) == pytest.approx(1.0)
        assert fluctuation_intensity(y_6,6,7) == pytest.approx(0.027777777777777776)
        assert fluctuation_intensity(y_7,6,7) == pytest.approx(0.5833333333333334)
        
    def test_bad_series(self):
        y_1 = [1,2,3,4,5,6]
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            fluctuation_intensity(y_1,6,6)
        expected_error_msg = "Given time series is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_bad_scale(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            fluctuation_intensity(y_1,float(6),6)
        expected_error_msg = "Given scale is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_bad_window(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            fluctuation_intensity(y_1,6,"6")
        expected_error_msg = "Given window length is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_neg_scale(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            fluctuation_intensity(y_1,-6,6)
        expected_error_msg = "Given scale is negative."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_large_window(self):
        y_1 = np.array([1,2,3,4,5,6])
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            fluctuation_intensity(y_1,6,10)
        expected_error_msg = "Improper window length."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jan 19 12:20:09 2021

@author: arsii

Test for time series decomposition.

"""

import pytest

from tscfat.Utils.argument_loader import setup_np, setup_pd
from tscfat.Analysis.decompose_timeseries import STL_decomposition, _plot_decomposition

class TestDecomposeTimeseries(object):
                
    def test_STL_decomposition(self):
        """ Test STL_decomposition function. Test passes with proper arguments
        and raises an AssertionError if the input time series is not numpy 
        array.
    
        Returns
        -------
        None.
    
        """
        
        res = STL_decomposition(setup_np(),'Test title', test=True) 
        assert res is not None
        assert res.observed.all() is not None
        assert res.trend.all() is not None
        assert res.seasonal.all() is not None
        assert res.resid.all() is not None
        
        test_argument = setup_pd()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            STL_decomposition(test_argument,'Test title', test=True)
        expected_error_msg = "Series is not a numpy array."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_STL_decomposition_proper(self):
        """ Test that the STL_decomposition returns something.
        

        Returns
        -------
        None.

        """
        
        test_argument = setup_np()
        res = STL_decomposition(test_argument,'Test title', test=True)
        
        assert res is not None

    def test_plot_decomposition(self):
        """ Test that the _plot_decomposition returns something.
        

        Returns
        -------
        None.

        """
        
        test_argument = setup_np()
        res = STL_decomposition(test_argument,'Test title', test=True)
        fig = _plot_decomposition(res,
                                  title="test",
                                  savepath = False,
                                  savename = False,
                                  dates = False,
                                  test = True,
                                  )
        assert fig is not None


# -*- coding: utf-8 -*-
"""
Created on Fri Jan 15 15:15:03 2021

@author: arsii

Test for rolling statistics.

"""
import pytest
import numpy as np

from tscfat.Utils.argument_loader import setup_np, setup_pd, setup_ps
from tscfat.Analysis.rolling_statistics import rolling_statistics, _autocorr

#TODO! write docstrings
#TODO! check test with proper arguments

class TestRollingStatistics(object):
    
    
    def test_rolling_statistics(self):
        """
        Test with proper arguments.
    
        Returns
        -------
        None.
    
        """
        test_argument = setup_pd()
        test_argument = test_argument['level'].to_frame()
        res = rolling_statistics(test_argument, w = 7, savename = False, savepath = False, test = True)
        print(type(res))
        assert res is not None, 'Function returned a None object.' 
    
        
    def test_rolling_statistics_ts(self):
        """
        Given a numpy array, Rolling_statistics raises an error.
    
        Returns
        -------
        None.
    
        """
        test_argument = setup_np()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            rolling_statistics(test_argument,w=7)
        expected_error_msg = "Timeseries is not a pandas dataframe."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    
    def test_rolling_statistics_w(self):
        """
        Given window size as a string, Rolling_statistics raises an error.
    
        Returns
        -------
        None.
    
        """
        test_argument = setup_pd()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            rolling_statistics(test_argument,w=str(7))
        expected_error_msg = "Window size is not an integer."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)  
        
    def test_rolling_statistics_long_window(self):
        """
        Given too large window size, Rolling_statistics raises an error.
    
        Returns
        -------
        None.
    
        """
        test_argument = setup_pd()
        # Store information about raised ValueError in exc_info
        with pytest.raises(AssertionError) as exc_info:
            rolling_statistics(test_argument,w=10000000)
        expected_error_msg = "Window length is larger than the time series length."
        # Check if the raised ValueError contains the correct message
        assert exc_info.match(expected_error_msg)
        
    def test_autocorr(self):
        test_argument = setup_ps()
        ac = _autocorr(test_argument)
        assert isinstance(ac, np.float64)
    